@@ -1,17 +1,15 @@
 /*
-  SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef COLLECTIONGENERALWIDGET_H
-#define COLLECTIONGENERALWIDGET_H
+#pragma once
 
 #include "mailcommon_export.h"
-#include <AkonadiCore/Collection>
+#include <Akonadi/Collection>
 #include <QWidget>
 class QCheckBox;
-class QVBoxLayout;
 namespace KIdentityManagement
 {
 class IdentityCombo;
@@ -29,7 +27,6 @@ public:
     void load(const Akonadi::Collection &col);
 
 private:
-    void addLine(QWidget *parent, QVBoxLayout *layout);
     void slotIdentityCheckboxChanged();
     QCheckBox *mNotifyOnNewMailCheckBox = nullptr;
     QCheckBox *mKeepRepliesInSameFolderCheckBox = nullptr;
@@ -39,4 +36,3 @@ private:
     QSharedPointer<MailCommon::FolderSettings> mFolderCollection;
 };
 }
-#endif // COLLECTIONGENERALWIDGET_H
