@@ -1,15 +1,15 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "invalidfilterdialogtest.h"
 #include "../filter/invalidfilters/invalidfilterdialog.h"
-#include <QTest>
-#include "../filter/invalidfilters/invalidfilterwidget.h"
 #include "../filter/invalidfilters/invalidfilterinfowidget.h"
+#include "../filter/invalidfilters/invalidfilterwidget.h"
 #include <QStandardPaths>
+#include <QTest>
 
 InvalidFilterDialogTest::InvalidFilterDialogTest(QObject *parent)
     : QObject(parent)
@@ -17,9 +17,7 @@ InvalidFilterDialogTest::InvalidFilterDialogTest(QObject *parent)
     QStandardPaths::setTestModeEnabled(true);
 }
 
-InvalidFilterDialogTest::~InvalidFilterDialogTest()
-{
-}
+InvalidFilterDialogTest::~InvalidFilterDialogTest() = default;
 
 void InvalidFilterDialogTest::shouldHaveDefaultValue()
 {
