@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -30,7 +30,9 @@ private:
     void slotMoveDown();
     void slotEnableControls();
     void slotEnableAccountOrder(bool state);
-    enum Type { IdentifierAccount = Qt::UserRole + 1 };
+    enum Type {
+        IdentifierAccount = Qt::UserRole + 1,
+    };
 
     void writeConfig();
     void readConfig();
@@ -38,4 +40,3 @@ private:
     std::unique_ptr<AccountConfigOrderDialogPrivate> const d;
 };
 }
-
