@@ -1,6 +1,6 @@
 /*
 
-  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -61,7 +61,10 @@ public:
     void setEnableDragDrop(bool enabled);
 
 protected:
-    enum Move { Next = 0, Previous = 1 };
+    enum Move {
+        Next = 0,
+        Previous = 1,
+    };
 
     void init(bool showUnreadCount);
     void selectModelIndex(const QModelIndex &);
@@ -112,4 +115,3 @@ private:
     bool mbDisableSaveConfig = false;
 };
 }
-
